@@ -1,15 +1,19 @@
 var classgko_1_1matrix_1_1Csr =
 [
-    [ "automatical", "classgko_1_1matrix_1_1Csr_1_1automatical.html", "classgko_1_1matrix_1_1Csr_1_1automatical" ],
-    [ "classical", "classgko_1_1matrix_1_1Csr_1_1classical.html", "classgko_1_1matrix_1_1Csr_1_1classical" ],
-    [ "cusparse", "classgko_1_1matrix_1_1Csr_1_1cusparse.html", "classgko_1_1matrix_1_1Csr_1_1cusparse" ],
-    [ "load_balance", "classgko_1_1matrix_1_1Csr_1_1load__balance.html", "classgko_1_1matrix_1_1Csr_1_1load__balance" ],
-    [ "merge_path", "classgko_1_1matrix_1_1Csr_1_1merge__path.html", "classgko_1_1matrix_1_1Csr_1_1merge__path" ],
-    [ "permuting_reuse_info", "structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info.html", "structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info" ],
-    [ "sparselib", "classgko_1_1matrix_1_1Csr_1_1sparselib.html", "classgko_1_1matrix_1_1Csr_1_1sparselib" ],
     [ "strategy_type", "classgko_1_1matrix_1_1Csr_1_1strategy__type.html", "classgko_1_1matrix_1_1Csr_1_1strategy__type" ],
+    [ "classical", "classgko_1_1matrix_1_1Csr_1_1classical.html", "classgko_1_1matrix_1_1Csr_1_1classical" ],
+    [ "merge_path", "classgko_1_1matrix_1_1Csr_1_1merge__path.html", "classgko_1_1matrix_1_1Csr_1_1merge__path" ],
+    [ "cusparse", "classgko_1_1matrix_1_1Csr_1_1cusparse.html", "classgko_1_1matrix_1_1Csr_1_1cusparse" ],
+    [ "sparselib", "classgko_1_1matrix_1_1Csr_1_1sparselib.html", "classgko_1_1matrix_1_1Csr_1_1sparselib" ],
+    [ "load_balance", "classgko_1_1matrix_1_1Csr_1_1load__balance.html", "classgko_1_1matrix_1_1Csr_1_1load__balance" ],
+    [ "automatical", "classgko_1_1matrix_1_1Csr_1_1automatical.html", "classgko_1_1matrix_1_1Csr_1_1automatical" ],
+    [ "multiply_reuse_info", "classgko_1_1matrix_1_1Csr_1_1multiply__reuse__info.html", "classgko_1_1matrix_1_1Csr_1_1multiply__reuse__info" ],
+    [ "multiply_add_reuse_info", "classgko_1_1matrix_1_1Csr_1_1multiply__add__reuse__info.html", "classgko_1_1matrix_1_1Csr_1_1multiply__add__reuse__info" ],
+    [ "scale_add_reuse_info", "classgko_1_1matrix_1_1Csr_1_1scale__add__reuse__info.html", "classgko_1_1matrix_1_1Csr_1_1scale__add__reuse__info" ],
+    [ "permuting_reuse_info", "structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info.html", "structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info" ],
     [ "Csr", "classgko_1_1matrix_1_1Csr.html#a9094bdf34a8c56f115252f0fe5a7f5ae", null ],
     [ "Csr", "classgko_1_1matrix_1_1Csr.html#aee53e78f8b1f8e3d2a6c407baac456d9", null ],
+    [ "add_scale_reuse", "classgko_1_1matrix_1_1Csr.html#acdc158c60660d50703c2bc3cf97f4fb1", null ],
     [ "compute_absolute", "classgko_1_1matrix_1_1Csr.html#a2435b1ff883ca33fa3874bc81aada57b", null ],
     [ "compute_absolute_inplace", "classgko_1_1matrix_1_1Csr.html#ab4cc1ed324551291d385d317e75ad256", null ],
     [ "conj_transpose", "classgko_1_1matrix_1_1Csr.html#af57eb59b5acb36cae0b3a16ffff9cf4f", null ],
@@ -30,6 +34,10 @@ var classgko_1_1matrix_1_1Csr =
     [ "get_strategy", "classgko_1_1matrix_1_1Csr.html#abb20626b04360436259fdc13b00e59b0", null ],
     [ "get_values", "classgko_1_1matrix_1_1Csr.html#ade22bdc09b0ef6d9740feeaa702fdd51", null ],
     [ "inv_scale", "classgko_1_1matrix_1_1Csr.html#a3ed41ecd59dcfe1b805ed910fada56a9", null ],
+    [ "multiply", "classgko_1_1matrix_1_1Csr.html#aab232ee1dfd8b84881e66260cf850cd5", null ],
+    [ "multiply_add", "classgko_1_1matrix_1_1Csr.html#a3cc824322b23f2256718c761841ece8e", null ],
+    [ "multiply_add_reuse", "classgko_1_1matrix_1_1Csr.html#a058af579839922bae27da8bb42f94b66", null ],
+    [ "multiply_reuse", "classgko_1_1matrix_1_1Csr.html#a091a0013a0ef9a17d2cbf5ac5f09e06b", null ],
     [ "operator=", "classgko_1_1matrix_1_1Csr.html#a0f8038628e96f1995e4942863415ad63", null ],
     [ "operator=", "classgko_1_1matrix_1_1Csr.html#a96d132e8d22d7565f93540eb50bcc32c", null ],
     [ "permute", "classgko_1_1matrix_1_1Csr.html#a898b9b458ff9e26c87c277fba3a9bdae", null ],
@@ -37,6 +45,7 @@ var classgko_1_1matrix_1_1Csr =
     [ "permute_reuse", "classgko_1_1matrix_1_1Csr.html#a05d792d40944735476606320d91290f4", null ],
     [ "permute_reuse", "classgko_1_1matrix_1_1Csr.html#a6059f7474424460e1e0c25f5bf2c7c37", null ],
     [ "scale", "classgko_1_1matrix_1_1Csr.html#ad1db62aaad519a9774dde49ff411edde", null ],
+    [ "scale_add", "classgko_1_1matrix_1_1Csr.html#a4a9bcad293b828a49dac453195abd212", null ],
     [ "scale_permute", "classgko_1_1matrix_1_1Csr.html#a1c3c66d3baf3b05e52992b6f3f7611f7", null ],
     [ "scale_permute", "classgko_1_1matrix_1_1Csr.html#acf9d804a766061d117e78a3534b2e80d", null ],
     [ "set_strategy", "classgko_1_1matrix_1_1Csr.html#a3e0f6f2a9d773de0551068d514bf9703", null ],
