@@ -9,24 +9,24 @@ var searchData=
   ['window_6',['window',['../classgko_1_1experimental_1_1mpi_1_1window.html',1,'gko::experimental::mpi::window&lt; ValueType &gt;'],['../classgko_1_1experimental_1_1mpi_1_1window.html#a0d8b46cb4e781ef71bccbbfb4a9407fe',1,'gko::experimental::mpi::window::window()'],['../classgko_1_1experimental_1_1mpi_1_1window.html#ae4fca6434fa04ac9b8e9071bfc8cfe70',1,'gko::experimental::mpi::window::window(window &amp;&amp;other)'],['../classgko_1_1experimental_1_1mpi_1_1window.html#aa4604e5b67e90562628e9c3811383195',1,'gko::experimental::mpi::window::window(std::shared_ptr&lt; const Executor &gt; exec, ValueType *base, int num_elems, const communicator &amp;comm, const int disp_unit=sizeof(ValueType), MPI_Info input_info=MPI_INFO_NULL, create_type c_type=create_type::create)']]],
   ['windows_7',['Building Ginkgo in Windows',['../install_ginkgo.html#autotoc_md1',1,'']]],
   ['with_20hip_20support_8',['Building Ginkgo with HIP support',['../install_ginkgo.html#autotoc_md2',1,'']]],
-  ['with_20the_20gpe_20optional_9',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
-  ['with_5fl_5fsolver_10',['with_l_solver',['../structgko_1_1preconditioner_1_1Ic_1_1parameters__type.html#a27fb2f5820de064959fbf2eefe201549',1,'gko::preconditioner::Ic::parameters_type::with_l_solver()'],['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a0a1d24fbe041045f15ef9385a1784366',1,'gko::preconditioner::Ilu::parameters_type::with_l_solver()']]],
-  ['with_5floggers_11',['with_loggers',['../classgko_1_1enable__parameters__type.html#a6ecac33b17246bfea802ebaf23c189b4',1,'gko::enable_parameters_type']]],
-  ['with_5fmatrix_5ftype_12',['with_matrix_type',['../namespacegko.html#a537803d962d07cf43e1e0cbc9f6a3f8b',1,'gko']]],
-  ['with_5fu_5fsolver_13',['with_u_solver',['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a542a9a8066d367167925042d3443c4a2',1,'gko::preconditioner::Ilu::parameters_type']]],
-  ['workflow_14',['Our git workflow',['../contributing_guidelines.html#autotoc_md24',1,'']]],
-  ['workspace_5ftraits_15',['workspace_traits',['../structgko_1_1solver_1_1workspace__traits.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20bicg_3c_20valuetype_20_3e_20_3e_16',['workspace_traits&lt; Bicg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Bicg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20bicgstab_3c_20valuetype_20_3e_20_3e_17',['workspace_traits&lt; Bicgstab&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Bicgstab_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20cg_3c_20valuetype_20_3e_20_3e_18',['workspace_traits&lt; Cg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Cg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20cgs_3c_20valuetype_20_3e_20_3e_19',['workspace_traits&lt; Cgs&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Cgs_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20chebyshev_3c_20valuetype_20_3e_20_3e_20',['workspace_traits&lt; Chebyshev&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Chebyshev_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20fcg_3c_20valuetype_20_3e_20_3e_21',['workspace_traits&lt; Fcg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Fcg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20gcr_3c_20valuetype_20_3e_20_3e_22',['workspace_traits&lt; Gcr&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Gcr_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20gko_3a_3aexperimental_3a_3asolver_3a_3adirect_3c_20valuetype_2c_20indextype_20_3e_20_3e_23',['workspace_traits&lt; gko::experimental::solver::Direct&lt; ValueType, IndexType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01gko_1_1experimental_1_1solver_1_1Direct_3_01ValueType_00_01IndexType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20gmres_3c_20valuetype_20_3e_20_3e_24',['workspace_traits&lt; Gmres&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Gmres_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20idr_3c_20valuetype_20_3e_20_3e_25',['workspace_traits&lt; Idr&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Idr_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
-  ['workspace_5ftraits_3c_20ir_3c_20valuetype_20_3e_20_3e_26',['workspace_traits&lt; Ir&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Ir_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
+  ['with_20make_20benchmark_20or_20run_5fall_5fbenchmarks_20sh_9',['4: Benchmarking with &lt;span class=&quot;tt&quot;&gt;make benchmark&lt;/span&gt; or &lt;span class=&quot;tt&quot;&gt;run_all_benchmarks.sh&lt;/span&gt;',['../benchmarking_ginkgo.html#autotoc_md14',1,'']]],
+  ['with_20the_20gpe_20optional_10',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
+  ['with_5fl_5fsolver_11',['with_l_solver',['../structgko_1_1preconditioner_1_1Ic_1_1parameters__type.html#a27fb2f5820de064959fbf2eefe201549',1,'gko::preconditioner::Ic::parameters_type::with_l_solver()'],['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a0a1d24fbe041045f15ef9385a1784366',1,'gko::preconditioner::Ilu::parameters_type::with_l_solver()']]],
+  ['with_5floggers_12',['with_loggers',['../classgko_1_1enable__parameters__type.html#a6ecac33b17246bfea802ebaf23c189b4',1,'gko::enable_parameters_type']]],
+  ['with_5fmatrix_5ftype_13',['with_matrix_type',['../namespacegko.html#a537803d962d07cf43e1e0cbc9f6a3f8b',1,'gko']]],
+  ['with_5fu_5fsolver_14',['with_u_solver',['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a542a9a8066d367167925042d3443c4a2',1,'gko::preconditioner::Ilu::parameters_type']]],
+  ['workflow_15',['Our git workflow',['../contributing_guidelines.html#autotoc_md24',1,'']]],
+  ['workspace_5ftraits_16',['workspace_traits',['../structgko_1_1solver_1_1workspace__traits.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20bicg_3c_20valuetype_20_3e_20_3e_17',['workspace_traits&lt; Bicg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Bicg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20bicgstab_3c_20valuetype_20_3e_20_3e_18',['workspace_traits&lt; Bicgstab&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Bicgstab_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20cg_3c_20valuetype_20_3e_20_3e_19',['workspace_traits&lt; Cg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Cg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20cgs_3c_20valuetype_20_3e_20_3e_20',['workspace_traits&lt; Cgs&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Cgs_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20chebyshev_3c_20valuetype_20_3e_20_3e_21',['workspace_traits&lt; Chebyshev&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Chebyshev_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20fcg_3c_20valuetype_20_3e_20_3e_22',['workspace_traits&lt; Fcg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Fcg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20gcr_3c_20valuetype_20_3e_20_3e_23',['workspace_traits&lt; Gcr&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Gcr_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20gko_3a_3aexperimental_3a_3asolver_3a_3adirect_3c_20valuetype_2c_20indextype_20_3e_20_3e_24',['workspace_traits&lt; gko::experimental::solver::Direct&lt; ValueType, IndexType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01gko_1_1experimental_1_1solver_1_1Direct_3_01ValueType_00_01IndexType_01_4_01_4.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20gmres_3c_20valuetype_20_3e_20_3e_25',['workspace_traits&lt; Gmres&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Gmres_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
+  ['workspace_5ftraits_3c_20idr_3c_20valuetype_20_3e_20_3e_26',['workspace_traits&lt; Idr&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Idr_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
   ['workspace_5ftraits_3c_20lowertrs_3c_20valuetype_2c_20indextype_20_3e_20_3e_27',['workspace_traits&lt; LowerTrs&lt; ValueType, IndexType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01LowerTrs_3_01ValueType_00_01IndexType_01_4_01_4.html',1,'gko::solver']]],
   ['workspace_5ftraits_3c_20minres_3c_20valuetype_20_3e_20_3e_28',['workspace_traits&lt; Minres&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Minres_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
   ['workspace_5ftraits_3c_20multigrid_20_3e_29',['workspace_traits&lt; Multigrid &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Multigrid_01_4.html',1,'gko::solver']]],
@@ -39,7 +39,7 @@ var searchData=
   ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20double_20_3e_2c_20int64_20_3e_36',['WritableToMatrixData&lt; std::complex&lt; double &gt;, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
   ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20float_20_3e_2c_20int32_20_3e_37',['WritableToMatrixData&lt; std::complex&lt; float &gt;, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
   ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20float_20_3e_2c_20int64_20_3e_38',['WritableToMatrixData&lt; std::complex&lt; float &gt;, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
-  ['write_39',['write',['../classgko_1_1WritableToMatrixData.html#a96036c3a4bf4c67fa93002808b8b14e2',1,'gko::WritableToMatrixData::write()'],['../classgko_1_1log_1_1ProfilerHook_1_1SummaryWriter.html#a427ff4169c674ce517e93000fffd65b6',1,'gko::log::ProfilerHook::SummaryWriter::write()'],['../classgko_1_1log_1_1ProfilerHook_1_1TableSummaryWriter.html#a2f2a866829b190a4866c873fe9f1d4af',1,'gko::log::ProfilerHook::TableSummaryWriter::write()'],['../namespacegko.html#a82d427878e771fc00144d6d2dd4f4e64',1,'gko::write(StreamType &amp;&amp;os, MatrixPtrType &amp;&amp;matrix, layout_type layout=detail::mtx_io_traits&lt; std::remove_cv_t&lt; detail::pointee&lt; MatrixPtrType &gt; &gt; &gt;::default_layout)']]],
+  ['write_39',['write',['../classgko_1_1WritableToMatrixData.html#a96036c3a4bf4c67fa93002808b8b14e2',1,'gko::WritableToMatrixData::write()'],['../classgko_1_1log_1_1ProfilerHook_1_1SummaryWriter.html#a427ff4169c674ce517e93000fffd65b6',1,'gko::log::ProfilerHook::SummaryWriter::write()'],['../classgko_1_1log_1_1ProfilerHook_1_1TableSummaryWriter.html#a2f2a866829b190a4866c873fe9f1d4af',1,'gko::log::ProfilerHook::TableSummaryWriter::write()'],['../namespacegko.html#af82d8f7795fefcf5f38a38895e316c02',1,'gko::write(StreamType &amp;&amp;os, MatrixPtrType &amp;&amp;matrix, layout_type layout=detail::mtx_io_traits&lt; std::remove_cv_t&lt; detail::pointee&lt; MatrixPtrType &gt; &gt; &gt;::default_layout)'],['../namespacegko.html#abc28c235c3fbbf3c495b1850c61746d2',1,'gko::write(std::ostream &amp;os, ptr_param&lt; const LinOp &gt; matrix)']]],
   ['write_5fbinary_40',['write_binary',['../namespacegko.html#aba9ca89ef08421197d3dbf84b0ad884c',1,'gko']]],
   ['write_5fbinary_5fraw_41',['write_binary_raw',['../namespacegko.html#a3b27a0c0282115116c160884dc0a9468',1,'gko']]],
   ['write_5fnested_42',['write_nested',['../classgko_1_1log_1_1ProfilerHook_1_1NestedSummaryWriter.html#a3f4bcc48ba9fedd51538adc74e00f3a8',1,'gko::log::ProfilerHook::NestedSummaryWriter::write_nested()'],['../classgko_1_1log_1_1ProfilerHook_1_1TableSummaryWriter.html#a983a06c472660155ce7edc1cdfbbceda',1,'gko::log::ProfilerHook::TableSummaryWriter::write_nested()']]],
