@@ -1,7 +1,7 @@
 var searchData=
 [
   ['data_0',['data',['../classgko_1_1accessor_1_1row__major.html#aa83eec10535e8ac7f79c6a04c0c05b4c',1,'gko::accessor::row_major']]],
-  ['default_5finitial_5fguess_1',['default_initial_guess',['../structgko_1_1solver_1_1Chebyshev_1_1parameters__type.html#a7a41a9b17c2728165d98a87988214a6b',1,'gko::solver::Chebyshev::parameters_type::default_initial_guess'],['../structgko_1_1solver_1_1Ir_1_1parameters__type.html#a2e781c6001020deca1547e734e1bf16f',1,'gko::solver::Ir::parameters_type::default_initial_guess'],['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#a6f9a8a0ea54a9865cb0d2f62e0d8fc8e',1,'gko::solver::Multigrid::parameters_type::default_initial_guess']]],
+  ['default_5finitial_5fguess_1',['default_initial_guess',['../structgko_1_1solver_1_1Chebyshev_1_1parameters__type.html#a7a41a9b17c2728165d98a87988214a6b',1,'gko::solver::Chebyshev::parameters_type::default_initial_guess'],['../structgko_1_1solver_1_1parameters__type.html#a7a56369b741490e04c129ed2f032c36a',1,'gko::solver::parameters_type::default_initial_guess'],['../structgko_1_1solver_1_1Multigrid_1_1parameters__type.html#a6f9a8a0ea54a9865cb0d2f62e0d8fc8e',1,'gko::solver::Multigrid::parameters_type::default_initial_guess']]],
   ['deterministic_2',['deterministic',['../structgko_1_1multigrid_1_1Pgm_1_1parameters__type.html#a3c2ddfd2af200acc414f0e2af404e431',1,'gko::multigrid::Pgm::parameters_type::deterministic'],['../structgko_1_1solver_1_1Idr_1_1parameters__type.html#a79841ca6357faf532aeb2f8cd513d92b',1,'gko::solver::Idr::parameters_type::deterministic']]],
   ['deterministic_5fsample_3',['deterministic_sample',['../structgko_1_1factorization_1_1ParIct_1_1parameters__type.html#a703c9694aeb35d519bfea0e28710d699',1,'gko::factorization::ParIct::parameters_type::deterministic_sample'],['../structgko_1_1factorization_1_1ParIlut_1_1parameters__type.html#aa990e68efa7bb0695ff8dc587c4084fe',1,'gko::factorization::ParIlut::parameters_type::deterministic_sample']]],
   ['dimensionality_4',['dimensionality',['../classgko_1_1range.html#a6796721a162561502474e3150f179167',1,'gko::range::dimensionality'],['../classgko_1_1accessor_1_1row__major.html#ae969fbac55f5ba6e6f95f25a0aac483d',1,'gko::accessor::row_major::dimensionality']]],
